/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
// test_demo_polymorphic.cpp

// (C) Copyright 2002 Robert Ramey - http://www.rrsd.com . 
// Use, modification and distribution is subject to the Boost Software
// License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)

#include "test_tools.hpp"
#define main test_main
#include "../example/demo_polymorphic.cpp"
